OC.L10N.register(
    "mail",
    {
    "Personal" : "ສ່ວນບຸກຄົນ",
    "Mail" : "ຈົດໝາຍ",
    "Save" : "ບັນທຶກ",
    "Name" : "ຊື່",
    "Password" : "ລະຫັດຜ່ານ",
    "None" : "ບໍ່ມີ",
    "Change name" : "ປ່ຽນຊື່",
    "Cancel" : "ຍົກເລີກ",
    "Accounts" : "ບັນຊີ",
    "General" : "ທົ່ວໄປ",
    "About" : "ກ່ຽວກັບ",
    "Delete" : "ລຶບ",
    "Search" : "ຄົ້ນຫາ",
    "Send" : "ສົ່ງ",
    "Refresh" : "Refresh",
    "Choose" : "ເລືອກ",
    "Confirm" : "ຢືນຢັນ",
    "Unfavorite" : "ລາຍການທີ່ບໍ່ມັກ",
    "Favorite" : "ລາຍການທີ່ມັກ",
    "Back" : "ຫຼັງ",
    "Create" : "ສ້າງ",
    "Select" : "ເລືອກ",
    "Remove" : "ຍ້າຍອອກ",
    "Forward" : "ໄປຂ້າງຫນ້າ",
    "Translate" : "ແປ",
    "Show images" : "ສະເເດງຮູບພາບ",
    "Move" : "ຍ້າຍ",
    "Loading …" : "ກຳລັງໂຫຼດ",
    "Remove account" : "ຍ້າຍບັນຊີ",
    "Quota" : "ການໃຊ້ຮ່ວມກັນໄດ້",
    "Clear cache" : "ລ້າງ Cache ",
    "Add" : "ເພີ່ມ",
    "Close" : "ປິດ",
    "Date" : "ວັນທີ",
    "Tags" : "ປ້າຍກຳກັບ",
    "Favorites" : "ລາຍການທີ່ມັກ"
},
"nplurals=1; plural=0;");
